IdfaData class

Constructors

IdfaData(bool adTrackingEnabled, String? advertisingId, TrackingStatus? trackingStatus)

Properties

adTrackingEnabled → bool
final
advertisingId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingStatus → TrackingStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited