PluginIdfa class

Inheritance

Constructors

PluginIdfa({bool shouldAskPermission = true})

Properties

analytics → Analytics?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pAnalytics ↔ Analytics?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PluginType
finalinherited

Methods

clear() → void
inherited
configure(Analytics analytics) → void
inherited
execute(RawEvent event) → Future<RawEvent?>
override
getTrackingStatus() → Future<IdfaData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestTrackingPermission() → Future<bool>
requestTrackingPermission() will prompt the user for tracking permission and returns a promise you can use to make additional tracking decisions based on the user response
shutdown() → void
inherited
toString() → String
A string representation of this object.
inherited
update(Map<String, dynamic> settings, ContextUpdateType type) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited